@@ -6,7 +6,18 @@ GCP_PROJECT = os.environ["GCP_PROJECT"]
 FUNCTION_REGION = os.environ["FUNCTION_REGION"]
 
 
-def _get_service_account_token(audience):
+def _get_oidc_token(audience):
+    if os.getenv("LOCAL"):
+        from subprocess import Popen, PIPE
+
+        return (
+            Popen(
+                ["gcloud", "auth", "print-identity-token", "--audiences=" + audience],
+                stdout=PIPE,
+            )
+            .communicate()[0][:-1]
+            .decode()
+        )
     token_url = (
         "http://metadata.google.internal"
         "/computeMetadata/v1/instance/service-accounts/default/identity"
@@ -21,7 +32,7 @@ def call(name, data):
     try:
         domain = f"https://{FUNCTION_REGION}-{GCP_PROJECT}.cloudfunctions.net"
         url = urljoin(domain, name)
-        headers = {"Authorization": "Bearer " + _get_service_account_token(url)}
+        headers = {"Authorization": "Bearer " + _get_oidc_token(url)}
         r = requests.post(url, headers=headers, json=data)
         return {
             "success": r.status_code < 400,
